from miyadaiku.core.contents import get_content_from_package, bin_loader
from miyadaiku.core import config

FONTAWESOME_MIN = 'font-awesome.min.css'
FONTAWESOME = 'font-awesome.css'
DEST_PATH = '/static/fontawesome/css/'

def load_package(site):
    f = site.config.get('/', 'fontawesome_compressed')
    f = config.to_bool(f)
    fontawesome = FONTAWESOME_MIN if f else FONTAWESOME
    src_path = 'externals/css/'+fontawesome
    
    content = get_content_from_package(
        site, __name__, src_path, DEST_PATH+fontawesome, bin_loader)
    site.contents.add(content)
    site.config.add('/', {'fontawesome_path': DEST_PATH+fontawesome})



import os
import pathlib
from setuptools import setup, find_packages
from miyadaiku.common import setuputils

DIR = pathlib.Path(__file__).resolve().parent
os.chdir(DIR)


requires = [
    "miyadaiku"
]

srcdir = 'node_modules/font-awesome/'
destdir = 'miyadaiku/themes/fontawesome/externals'
filesdir = 'miyadaiku/themes/fontawesome/files'
copy_files = [
    [srcdir+'/css/', ['*.css'], destdir+'/css/'],
    [srcdir+'/fonts/', ['*', ], filesdir+'/static/fontawesome/fonts/']
]

setup(
    name="miyadaiku.themes.fontawesome",
    version="0.0.3",
    author="Atsuo Ishimoto",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
    ],
    description='Font Awesome files for miyadaiku static site generator',
    long_description=setuputils.read_file(DIR, 'README.rst'),
    packages=list(setuputils.list_packages(DIR, 'miyadaiku')),
    package_data={
        '': setuputils.SETUP_FILE_EXTS,
    },
    install_requires=requires,
    include_package_data=True,
    zip_safe=False,
    cmdclass={'copy_files': setuputils.copy_files},
    copy_files=copy_files
)
